@@ -14,6 +14,10 @@ $SUDO bash -c 'echo "SUBSYSTEMS==\"usb\", ATTRS{product}==\"CP2102 USB to UART B
 cd `dirname $0`
 ARCH=`uname -m`
 
+if [ "$XDG_SESSION_TYPE" = "wayland" ] ; then
+	export QT_XCB_GL_INTEGRATION=none
+fi  
+
 LD_LIBRARY_PATH=lib exec ./settings-$ARCH "$@"
 
 rm -f /tmp/.spirit-settings
